@@ -684,8 +684,10 @@ panel_menu_button_load (const char  *menu_path,
 
 	panel_applet_add_callback (info, "help", GTK_STOCK_HELP, _("_Help"), NULL);
 
-        if (panel_is_program_in_path ("gmenu-simple-editor"))
-		panel_applet_add_callback (info, "edit", NULL, _("_Edit Menus"), NULL);
+        if (panel_is_program_in_path ("alacarte") ||
+	    panel_is_program_in_path ("gmenu-simple-editor"))
+		panel_applet_add_callback (info, "edit", NULL,
+					   _("_Edit Menus"), NULL);
 
 	panel_widget_set_applet_expandable (panel, GTK_WIDGET (button), FALSE, TRUE);
 	panel_widget_set_applet_size_constrained (panel, GTK_WIDGET (button), TRUE);
@@ -997,10 +999,18 @@ panel_menu_button_invoke_menu (PanelMenuButton *button,
 	} else if (!strcmp (callback_name, "edit")) {
                 GError *error = NULL;
 
-		panel_launch_desktop_file ("gmenu-simple-editor.desktop",
-					   "gmenu-simple-editor",
+		panel_launch_desktop_file ("alacarte.desktop",
+					   "alacarte-editor",
 					   screen,
 					   &error);
+		if (error) {
+			g_error_free (error);
+			panel_launch_desktop_file ("gmenu-simple-editor.desktop",
+						   "gmenu-simple-editor",
+						   screen,
+						   &error);
+		}
+
                 if (error) {
                         panel_error_dialog (screen,
                                             "cannot_exec_gmenu-simple-editor", TRUE,
